--- old/usr/src/cmd/dumpadm/dconf.c	Thu Apr  9 05:09:28 2015
+++ new/usr/src/cmd/dumpadm/dconf.c	Thu Apr  9 05:09:28 2015
@@ -20,6 +20,7 @@
  */
 /*
  * Copyright (c) 1998, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright 2015 Nexenta Systems, Inc. All rights reserved.
  */
 
 #include <sys/types.h>
@@ -519,6 +520,23 @@
 	return (err == 0);
 }
 
+int
+dconf_get_dumpsize(dumpconf_t *dcp)
+{
+	char buf[32];
+	uint64_t d;
+
+	if (ioctl(dcp->dc_dump_fd, DIOCGETDUMPSIZE, &d) == -1) {
+		warn(gettext("failed to get kernel dump size"));
+		return (-1);
+	}
+
+	zfs_nicenum(d, buf, sizeof (buf));
+
+	(void) printf(gettext("Estimated dump size: %s\n"), buf);
+	return (0);
+}
+
 void
 dconf_print(dumpconf_t *dcp, FILE *fp)
 {
--- old/usr/src/cmd/dumpadm/dconf.h	Thu Apr  9 05:09:29 2015
+++ new/usr/src/cmd/dumpadm/dconf.h	Thu Apr  9 05:09:29 2015
@@ -20,6 +20,7 @@
  */
 /*
  * Copyright (c) 1998, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright 2015 Nexenta Systems, Inc. All rights reserved.
  */
 
 #ifndef	_DCONF_H
@@ -71,6 +72,7 @@
 extern int dconf_update(dumpconf_t *, int);
 extern void dconf_print(dumpconf_t *, FILE *);
 extern int dconf_write_uuid(dumpconf_t *);
+extern int dconf_get_dumpsize(dumpconf_t *);
 
 extern int dconf_str2device(dumpconf_t *, char *);
 extern int dconf_str2savdir(dumpconf_t *, char *);
--- old/usr/src/cmd/dumpadm/main.c	Thu Apr  9 05:09:29 2015
+++ new/usr/src/cmd/dumpadm/main.c	Thu Apr  9 05:09:29 2015
@@ -20,6 +20,7 @@
  */
 /*
  * Copyright (c) 1998, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright 2015 Nexenta Systems, Inc. All rights reserved.
  */
 
 #include <sys/stat.h>
@@ -34,10 +35,10 @@
 #include "utils.h"
 
 static const char USAGE[] = "\
-Usage: %s [-nuy] [-c kernel | curproc | all ] [-d dump-device | swap ]\n\
+Usage: %s [-enuy] [-c kernel | curproc | all ] [-d dump-device | swap ]\n\
 	[-m min {k|m|%%} ] [-s savecore-dir] [-r root-dir] [-z on|off]\n";
 
-static const char OPTS[] = "inuyc:d:m:s:r:z:";
+static const char OPTS[] = "einuyc:d:m:s:r:z:";
 
 static const char PATH_DEVICE[] = "/dev/dump";
 static const char PATH_CONFIG[] = "/etc/dumpadm.conf";
@@ -51,6 +52,7 @@
 	struct stat st;
 	int c;
 	int dflag = 0;			/* for checking in use during -d ops */
+	int eflag = 0;			/* print estimated dump size */
 	int dcmode = DC_CURRENT;	/* kernel settings override unless -u */
 	int modified = 0;		/* have we modified the dump config? */
 	char *minfstr = NULL;		/* string value of -m argument */
@@ -121,7 +123,9 @@
 				dflag++;
 				modified++;
 				break;
-
+			case 'e':
+				eflag++;
+				break;
 			case 'i':
 				/* undocumented option */
 				if (chrooted) {
@@ -168,6 +172,14 @@
 		}
 	}
 
+	if (eflag) {
+		if (argc == 2 && argv[1][0] == '-' && argv[1][1] == 'e' &&
+		    !argv[1][2])
+			return (dconf_get_dumpsize(&dc) ? E_SUCCESS : E_ERROR);
+		else
+			die(gettext("-e cannot be used with other options\n"));
+	}
+
 	if (douuid)
 		return (dconf_write_uuid(&dc) ? E_SUCCESS : E_ERROR);
 
--- old/usr/src/man/man1m/dumpadm.1m	Thu Apr  9 05:09:29 2015
+++ new/usr/src/man/man1m/dumpadm.1m	Thu Apr  9 05:09:29 2015
@@ -1,17 +1,17 @@
 '\" te
 .\" Copyright (c) 2008, Sun Microsystems, Inc. All Rights Reserved
-.\" Copyright 2013 Nexenta Systems, Inc.  All Rights Reserved.
+.\" Copyright 2015 Nexenta Systems, Inc.  All Rights Reserved.
 .\" Copyright (c) 2013 by Delphix. All rights reserved.
 .\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License").  You may not use this file except in compliance with the License.
 .\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing.  See the License for the specific language governing permissions and limitations under the License.
 .\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE.  If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH DUMPADM 1M "Feb 15, 2013"
+.TH DUMPADM 1M "Apr 09, 2015"
 .SH NAME
 dumpadm \- configure operating system crash dump
 .SH SYNOPSIS
 .LP
 .nf
-\fB/usr/sbin/dumpadm\fR [\fB-nuy\fR] [\fB-c\fR \fIcontent-type\fR] [\fB-d\fR \fIdump-device\fR]
+\fB/usr/sbin/dumpadm\fR [\fB-enuy\fR] [\fB-c\fR \fIcontent-type\fR] [\fB-d\fR \fIdump-device\fR]
      [\fB-m\fR \fImin\fRk | \fImin\fRm | \fImin\fR%] [\fB-s\fR \fIsavecore-dir\fR]
      [\fB-r\fR \fIroot-dir\fR] [\fB-z\fR on | off]
 .fi
@@ -186,6 +186,16 @@
 
 .RE
 
+.sp
+.ne 2
+.na
+\fB\fB-e\fR\fR
+.ad
+.sp .6
+.RS 4n
+Estimates the size of the dump for the current running system.
+.RE
+
 .sp
 .ne 2
 .na
